# android_change_package_identifier plugin

[![fastlane Plugin Badge](https://rawcdn.githack.com/fastlane/fastlane/master/fastlane/assets/plugin-badge.svg)](https://rubygems.org/gems/fastlane-plugin-android_change_package_identifier)

## Getting Started

This project is a [fastlane](https://github.com/fastlane/fastlane) plugin. To get started with `fastlane-plugin-android_change_package_identifier`, add it to your project by running:

```bash
fastlane add_plugin android_change_package_identifier
```

## About android_change_package_identifier

Change the package identifier in the AndroidManifest.xml file. Can revert as well.

Inupts:
```
newIdentifier: String (Optional)  // The new package identifier. Trumps appendToIdentifier
appendToIdentifier: String (Optional) // Append text to the package identifier after inserting a "."
manifest: String (Optional) // The location to your AndroidManifest.xml file.  Default: "app/src/main/AndroidManifest.xml"
```

Usage:

```
android_change_app_name(newIdentifier: "com.fake.newID")
android_change_app_name(newIdentifier: "com.fake.newID", manifest: "path/to/your/manifest.xml")
android_change_app_name(appendToIdentifier: "test") // would yield: com.fake.newID.test
```

Sets these keys

`ANDROID_CHANGE_PACKAGE_IDENTIFIER_ORIGINAL : String` = The original package identifier.

## About android_change_package_identifier_revert

Reverts the package identifier to the prior ANDROID_CHANGE_PACKAGE_IDENTIFIER_ORIGINAL value.  Errors if ANDROID_CHANGE_PACKAGE_IDENTIFIER_ORIGINAL is not set.

Inupts:
```
manifest: String (Optional) // The location to your AndroidManifest.xml file.  Default: "app/src/main/AndroidManifest.xml"
```

Usage:

```
android_change_package_identifier_revert()
android_change_package_identifier_revert(manifest: "path/to/your/manifest.xml")

```




## Example

Check out the [example `Fastfile`](fastlane/Fastfile) to see how to use this plugin. Try it by cloning the repo, running `fastlane install_plugins` and `bundle exec fastlane test`.

**Note to author:** Please set up a sample project to make it easy for users to explore what your plugin does. Provide everything that is necessary to try out the plugin in this project (including a sample Xcode/Android project if necessary)

## Run tests for this plugin

To run both the tests, and code style validation, run

```
rake
```

To automatically fix many of the styling issues, use
```
rubocop -a
```

## Issues and Feedback

For any other issues and feedback about this plugin, please submit it to this repository.

## Troubleshooting

If you have trouble using plugins, check out the [Plugins Troubleshooting](https://github.com/fastlane/fastlane/blob/master/fastlane/docs/PluginsTroubleshooting.md) doc in the main `fastlane` repo.

## Using `fastlane` Plugins

For more information about how the `fastlane` plugin system works, check out the [Plugins documentation](https://github.com/fastlane/fastlane/blob/master/fastlane/docs/Plugins.md).

## About `fastlane`

`fastlane` is the easiest way to automate beta deployments and releases for your iOS and Android apps. To learn more, check out [fastlane.tools](https://fastlane.tools).
